import {Component, OnInit} from '@angular/core';
import {fadeIn} from '../../animation/fade-in';
import {ApiService} from '../../service/api';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {Router} from '@angular/router';
import {TranslateService} from '@ngx-translate/core';

@Component({
  selector: 'app-gateway',
  templateUrl: './gateway.component.html',
  styles: [`
    :host ::ng-deep .anticon-filter {
      left: 73px;
    }
    .btnPart {
      padding: 10px;
    }
  `],
  animations: [fadeIn]
})
export class GatewayComponent implements OnInit {

  data = [];
  query = {
    gatewayName: '',
    gatewaySN: ''
  };
  isLoading = false;
  isAllCheck = false;
  isIndeterminate = false;
  page = 1;
  rows = 10;
  total = 125;
  listOfBind = [{text: '全部', value: 1}, {text: '已绑定', value: 2}, {text: '未绑定', value: 3}];
  selectedOne: any = {};
  isAddConV = false;
  isMultiAddConV = false;
  isBindConV = false;
  isMulti = false;
  canbind = false;
  canUnbind = false;
  isCheckedOne = false;
  isUpdateConV = false;
  isDivideConV = false;

  constructor(private api: ApiService, private message: NzMessageService, private router: Router,
              private modalService: NzModalService, private translate: TranslateService) {
  }

  ngOnInit() {
    this.init();
  }

  init() {
    this.getData();
  }

  next = (data) => {
    if (data && data.rows && data.rows.constructor === Array) {
      this.data = data.rows.filter(one => { one.isOn = Math.random() > 0.5; return one; });
      this.total = data.total;
    } else if (data.code === 1) {
      this.message.success(data && data.message ? data.message : '操作成功');
    } else if (data.code === 0) {
      this.message.error(data && data.message ? data.message : '操作失败');
    } else {
      this.message.error(data && data.message ? data.message : '获取数据失败');
    }
    this.isLoading = false;
  }

  getData() {
    this.isLoading = true;
    this.api.loginlog.getAll(this.page, this.rows, ['', this.next]);
  }

  onSearch() {
  }

  onGetAll() {
  }

  // 复选框的方法
  initCheckArray(b) {
    if (b) {
      this.isCheckedOne = true;
    }
    this.data.map((one) => one.checked = b);
  }

  checkAll(e) {
    this.isIndeterminate = false;
    this.initCheckArray(e);
    this.checkCanBind();
  }

  oneCheck() {
    this.isCheckedOne = true;
    this.isIndeterminate = false;
    this.isAllCheck = false;
    const sum = this.data.filter((one) => one.checked).length;
    if (sum === this.data.length) {
      this.isAllCheck = true;
    } else if (sum === 0) {
      this.isCheckedOne = false;
      this.canbind = false;
      this.canUnbind = false;
    } else {
      this.isIndeterminate = true;
    }
    this.checkCanBind();
  }

  checkCanBind() {
    const obj = this.data.filter(one => one.checked);
    if (obj.length === 0) {
      this.canbind = false;
      this.canUnbind = false;
    } else {
      const flag = obj[0].isOn;
      if (obj.filter(one => one.isOn === flag).length === obj.length) {
        this.canbind = flag;
        this.canUnbind = !flag;
      } else {
        this.canbind = false;
        this.canUnbind = false;
      }
    }
  }

  // 筛选
  filter(a, b) {
    console.log(a, b);
  }

  // 跳转详情
  toSee(e) {
    this.router.navigate(['/app/deviceCenter/gatewayMgr/gatewaySee']);
  }

  // 单个的方法
  add() {
    this.isMulti = false;
    this.isAddConV = true;
  }

  bind(one) {
    this.isMulti = false;
    this.selectedOne = one;
    this.isBindConV = true;
  }

  unbind(one) {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteSelectedRecord') + '</b>',
      nzOnOk   : () => this.unbindOne(one)
    });
  }

  unbindOne(one) {}

  update(one) {
    this.isMulti = false;
    this.selectedOne = one;
    this.isUpdateConV = true;
  }

  cancel(v) {
    this[v] = false;
  }

  save(v) {
    this[v] = false;
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {}

  // 批量的方法
  allUpdate() {
    this.isMulti = true;
    this.isUpdateConV = true;
  }

  multiAdd() {
    this.isMulti = true;
    this.isMultiAddConV = true;
  }

  allDivide() {
    this.isMulti = true;
    this.isDivideConV = true;
  }

  allBind() {
    this.isMulti = true;
    this.isBindConV = true;
  }

  allDelete() {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteSelectedRecord') + '</b>',
      nzOnOk   : () => this.deleteAll()
    });
  }

  deleteAll() {}

  allUnbind() {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmUnbindSelectedRecord') + '</b>',
      nzOnOk   : () => this.unbindAll()
    });
  }

  unbindAll() {}

  toggleOn(one) {
    one.isLoading = true;
    setTimeout(() => {
      one.isOn = !one.isOn;
      one.isLoading = false;
    }, 2000);
  }
}
