import {Component, OnInit} from '@angular/core';
import {ApiService} from '../../service/api';
import {NzMessageService, NzModalService} from 'ng-zorro-antd';
import {TranslateService} from '@ngx-translate/core';
import {fadeIn} from '../../animation/fade-in';
import {Router} from '@angular/router';

@Component({
  selector: 'app-module-mgr',
  templateUrl: './module-mgr.component.html',
  styles: [],
  animations: [fadeIn]
})
export class ModuleMgrComponent implements OnInit {

  req: any = {};
  data = [];
  isLoading = false;
  page: any = 1;
  rows: any = 10;
  total: any;
  isAddConV = false;
  isSaveOther = false;
  isUpdate = false;

  constructor(private api: ApiService, private message: NzMessageService, private modalService: NzModalService,
              private translate: TranslateService, private router: Router) {
  }

  ngOnInit() {
    this.getData();
  }

  getData() {
    this.isLoading = true;
    this.api.loginlog.getAll(this.page, this.rows, ['', this.next]);
  }

  onSearch() {
    this.page = 1;
    this.query();
  }

  query() {
    this.isLoading = true;
    const req = {
      startTime: this.req.startTime ? new Date(this.req.startTime).getTime() : '',
      endTime: this.req.endTime ? new Date(this.req.endTime).getTime() : ''
    };
    this.api.loginlog.getByTime(this.page, this.rows, [req, this.next]);
  }

  onGetAll() {
    this.page = 1;
    this.req = {};
    this.getData();
  }

  next = (data) => {
    if (data && data.rows && data.rows.constructor === Array) {
      this.data = data.rows;
      this.total = data.total;
    } else {
      this.message.error(data.message || this.translate.instant('wrongToGetData'));
    }
    this.isLoading = false;
  }

  searchData() {
    if (this.req.startTime || this.req.endTime) {
      this.query();
    } else {
      this.getData();
    }
  }

  toDetail() {
    this.router.navigate(['/app/deviceCenter/moduleMgr/moduleDetail']);
  }

  saveOther(one) {
    this.isSaveOther = true;
  }

  add() {
    this.isUpdate = false;
    this.isAddConV = true;
  }

  update(one) {
    this.isUpdate = true;
    this.isAddConV = true;
  }

  cancel(v) {
    this[v] = false;
  }

  save(v) {
    this[v] = false;
  }

  deleteConfirm(one) {
    this.modalService.confirm({
      nzTitle  : '<i> </i>',
      nzContent: '<b>' + this.translate.instant('confirmDeleteThisRecord') + '</b>',
      nzOnOk   : () => this.delete(one)
    });
  }

  delete(one) {}
}
